==> klass-model-meta-interface-0.3.0-sources.jar: cool/klass/model/meta/domain/api/visitor/DataTypePropertyVisitor.java <==
/*
 * Copyright 2024 Craig Motlin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cool.klass.model.meta.domain.api.visitor;

import cool.klass.model.meta.domain.api.property.EnumerationProperty;
import cool.klass.model.meta.domain.api.property.PrimitiveProperty;

public interface DataTypePropertyVisitor
{
    void visitEnumerationProperty(EnumerationProperty enumerationProperty);

    void visitString(PrimitiveProperty primitiveProperty);

    void visitInteger(PrimitiveProperty primitiveProperty);

    void visitLong(PrimitiveProperty primitiveProperty);

    void visitDouble(PrimitiveProperty primitiveProperty);

    void visitFloat(PrimitiveProperty primitiveProperty);

    void visitBoolean(PrimitiveProperty primitiveProperty);

    void visitInstant(PrimitiveProperty primitiveProperty);

    void visitLocalDate(PrimitiveProperty primitiveProperty);

    void visitTemporalInstant(PrimitiveProperty primitiveProperty);

    void visitTemporalRange(PrimitiveProperty primitiveProperty);
}

==> klass-model-meta-interface-0.5.0-sources.jar: cool/klass/model/meta/domain/api/visitor/DataTypePropertyVisitor.java <==
/*
 * Copyright 2024 Craig Motlin
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package cool.klass.model.meta.domain.api.visitor;

import cool.klass.model.meta.domain.api.property.EnumerationProperty;
import cool.klass.model.meta.domain.api.property.PrimitiveProperty;

public interface DataTypePropertyVisitor {
    void visitEnumerationProperty(EnumerationProperty enumerationProperty);

    void visitString(PrimitiveProperty primitiveProperty);

    void visitInteger(PrimitiveProperty primitiveProperty);

    void visitLong(PrimitiveProperty primitiveProperty);

    void visitDouble(PrimitiveProperty primitiveProperty);

    void visitFloat(PrimitiveProperty primitiveProperty);

    void visitBoolean(PrimitiveProperty primitiveProperty);

    void visitInstant(PrimitiveProperty primitiveProperty);

    void visitLocalDate(PrimitiveProperty primitiveProperty);

    void visitTemporalInstant(PrimitiveProperty primitiveProperty);

    void visitTemporalRange(PrimitiveProperty primitiveProperty);
}
